#include <AFMotor.h>

AF_DCMotor motor1(1, MOTOR12_64KHZ); // Definition du moteur 1 (celui de gauche)
AF_DCMotor motor2(2, MOTOR12_64KHZ);// Definition du moteur 2 (celui de droite)

// Capteur ultrason
int trigPin = 1;    // Trigger
int echoPin = 2;    // Echo
long duration, cm;
const unsigned long period = 1000;    // la valeur est un nombre de millisecondes
int timer;// compteur de temps (1 = 1000ms par exemple)
int directionRnd = 0;  // une variable random pour décider si la voiture va tourner à gauche ou à droite
int dernierDirection = 0;
bool commence = false; // Une variable pour savoir si la voiture doit rouler ou pas
char incomingByte; // Une variable lu par le port série

unsigned long startMillis;  //heure de début
unsigned long currentMillis; //heure actuelle

void setup()
{
  motor1.setSpeed(200);     // vitesse du moteur est figée à 200/255
  motor2.setSpeed(200);     // vitesse du moteur est figée à 200/255
  pinMode(trigPin, OUTPUT);// Mettre la variable trigPin en sortie 
  pinMode(echoPin, INPUT);// Mettre la variable echoPin en entrer
  Serial.begin(9600); // ouvre le port série, règle le débit de données à 9600 bps
  delay(random(500,2000));   // delay for random time
}

void loop()
{
  // Si l'Arduino a reçu une commande
  if (Serial.available() > 0) {
    // read the incoming byte:
    incomingByte = Serial.read();
    if(incomingByte == '1'){          // Si cette commande est 1, il s'arrete
      commence = false;
    }else if(incomingByte == '2'){    // Si cette commande est 2, il roule
      commence = true;
    }
  }
  if(commence){
    capteur(); // Fonction du capteur
    rouler(); // Fonction des mouvement de la voiture 
  }else{
    motor1.run(RELEASE);      //s'arreter
    motor2.run(RELEASE);      //s'arreter
  }
}


void rouler(){ // Fonction des mouvement de la voiture

  currentMillis = millis();  //recuperer le "temps" actuel (en fait, le nombre de millisecondes depuis le début du programme)
  if (currentMillis - startMillis >= period)  //tester si la période s'est écoulée
  {
    timer++; // incrementer le temps
    if (timer > 8) { // Si on atteint 8 (8000 ms)
      timer = 0; // remettre le timer a 0 s
      directionRnd = 0;
    }
    startMillis = currentMillis;  //IMPORTANT pour enregistrer l'heure de démarrage de l'état actuel de la LED.
  }

  if (cm >31)   // Si la distance est inferieur à 31cm     
  {
    //Serial.println(cm);
    motor1.run(FORWARD);      // Avancer
    motor2.run(FORWARD);      // Avancer
    dernierDirection = 1;
    Serial.print("wheels: ");
    Serial.println("1");       // la voiture bouge tout droit
  }
  else if (cm < 30) // Si la distance est superieur à 30cm 
  {
    if (timer >= 0 && timer <= 2.5) {
      motor1.run(RELEASE);      //s'arreter
      motor2.run(RELEASE);      //s'arreter
      Serial.print("wheels: ");
      Serial.println("3");       // la voiture arrete
      //delay(500);
    }else if (timer >= 2.5 && timer <= 5) {
      motor1.run(BACKWARD);      // Reculer
      motor2.run(BACKWARD);       // Reculer
      dernierDirection = 2;
      Serial.print("wheels: ");
      Serial.println("2");       // la voiture bouge en arriere
      //delay(500);
    }else if (timer >= 5 && timer <= 5.5) {
      motor1.run(RELEASE);      //s'arreter
      motor2.run(RELEASE);      //s'arreter
      Serial.print("wheels: ");
      Serial.println("3");       // la voiture arrete
      //delay(100);
    }else {
      if(directionRnd == 0){
        directionRnd = random(1,3);
      }
      if(directionRnd == 1){
        motor1.run(FORWARD);       // Avancer
        motor1.run(RELEASE);      // s'arreter
        Serial.print("wheels: ");
        if(dernierDirection == 1){
          Serial.println("6");       // la voiture tourne a gauche
        }else{
          Serial.println("7");       // la voiture tourne a droite
        }
      }else{
        motor2.run(FORWARD);       // Avancer
        motor2.run(RELEASE);      // s'arreter
        Serial.print("wheels: ");
        if(dernierDirection == 1){
          Serial.println("4");       // la voiture tourne a droite
        }else{
          Serial.println("5");       // la voiture tourne a gauche
        }
      }
      //delay(500);
    }
  }
}

void capteur(){ // Fonction du capteur

  digitalWrite(trigPin, LOW); // eteindre le trigPin rouge
  delayMicroseconds(5); // Pendant 5 microseconde
  digitalWrite(trigPin, HIGH);// Allumer le trigPin rouge
  delayMicroseconds(10); // Pendant 10 microseconde
  digitalWrite(trigPin, LOW);// eteindre le trigPin rouge

  pinMode(echoPin, INPUT); // Mettre la variable echoPin en entrer
  duration = pulseIn(echoPin, HIGH);// recuperer la durée

  // Convertir le temps en distance
  cm = (duration / 2) / 29.1;
  delay(10);// Pendant 10 microseconde
  Serial.print("distance: ");
  Serial.println(cm); // afficher la dictance en "cm"
}
